export type BreakpointKey = 'sm' | 'md' | 'lg' | 'xl';
export type ScreenSize = 'XS' | 'SM' | 'MD' | 'LG' | 'XL';
export declare const ScreenSizeArray: string[];
/**
 * 반응형 디자인을 위한 breakpoints.
 *
 * variables.scss 의 값과 일치해야 한다.
 */
export declare const BREAKPOINTS: Record<BreakpointKey, string>;
export declare const MEDIA_QUERIES: Record<BreakpointKey, string>;
export type ResponsiveConfig = {
    screenSize: ScreenSize;
};
export declare const responsiveUtil: {
    currentScreenSize(): ScreenSize;
    isScreenSizeSmallerThan(size: ScreenSize): boolean;
    isScreenSizeEqualOrSmallerThan(size: ScreenSize): boolean;
    isScreenSizeEqualOrGreaterThan(size: ScreenSize): boolean;
    isScreenSizeGreaterThan(size: ScreenSize): boolean;
};
export type BrowserSizeUtil = {
    /**
     * @return 현재 브라우저 크기
     */
    current(): ScreenSize;
    /**
     * @return 브라우저 크기가 XS, SM, MD 이면 true
     */
    isSmall(): boolean;
    /**
     * @return 브라우저 크기가 LG, XL 이면 true
     */
    isLarge(): boolean;
    /**
     * 'less than or equal to'
     * @param size
     * @return 브라우저 크기가 'size' 보다 작거나 같으면 true
     */
    le(size: ScreenSize): boolean;
    /**
     * 'greater than or equal to'
     * @param size
     * @return 브라우저 크기가 'size' 보다 크거가 같으면 true
     */
    ge(size: ScreenSize): boolean;
};
export declare const browserSize: BrowserSizeUtil;
